# -*- coding: utf-8 -*-
"""
/***************************************************************************
    A QGIS plugin for Road contamination modelling for EMSURE Project
                              -------------------
        begin                : 2015-04-20
        git sha              : $Format:%H$
        copyright            : (C) 2015 by Luigi Pirelli (for EMSURE project)
        email                : luipir@gmail.lcom
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""
# 2To3 python compatibility
from __future__ import print_function
from __future__ import unicode_literals

import subprocess
import time
import traceback
import platform
import os
import shutil

from PyQt4 import QtCore, QtGui

from qgis.utils import iface
from qgis.core import (QgsMessageLog,
                       QgsField)
from qgis.gui import (QgsMessageBar)

class Algorithm(QtCore.QObject):
    ''' the algorithm '''
    started = QtCore.pyqtSignal()
    progress = QtCore.pyqtSignal(int)
    message = QtCore.pyqtSignal(str, int)
    error = QtCore.pyqtSignal(Exception, basestring)
    finished = QtCore.pyqtSignal(object)
    
    def __init__(self):
        ''' constructor '''
        super(Algorithm, self).__init__()
        
        self.killed = False
 
    def run(self):
        ''' executable runner '''
        self.started.emit()
        
        # get algorithm executable
        executable = '/bin/ping'
        try:
            if platform.system() == 'Linux':
                command = [executable, '192.168.0.1']
            if platform.system() == 'Windows':
                command = [executable, '192.168.0.1']
            
            strCommand = ' '.join(command)
            msg = self.tr('Executing command {}'.format(strCommand))
            self.message.emit(msg, QgsMessageLog.INFO)
            
            proc = subprocess.Popen(command,
                                    stdout=subprocess.PIPE,
                                    stdin=subprocess.PIPE,
                                    stderr=subprocess.PIPE,
                                    cwd='./')
            self.progress.emit(-1)
            counter = 0
            for line in iter(proc.stdout.readline, ''):
                self.message.emit(line, QgsMessageLog.INFO)
                
                if self.killed:
                    break
                
                counter += 1
                if counter == 10:
                    break
            
        except Exception as ex:
            self.error.emit(ex, traceback.format_exc())
        
        # resturn true or false
        self.finished.emit(True)
                
    def kill(self):
        self.killed = True
    
    def tr(self, string, context=''):
        if not context:
            context = 'Test Thread Worker'
        return QtCore.QCoreApplication.translate(context, string)

    